@@ -1,4 +1,5 @@
 from abc import abstractmethod
+from ipey.helper import convertColor
 import xml.etree.ElementTree as ET
 import copy
 
@@ -25,6 +26,22 @@ class Primitive:
             self.rarrow = None
             self.arrow = None
 
+            self.__stroke_color_name = None
+            self.__fill_color_name = None
+            self.__stroke_color_value = None
+            self.__fill_color_value = None
+        
+    def getStrokeName(self):
+        return self.__stroke_color_name
+
+    def getStrokeValue(self):
+        return self.__stroke_color_value
+        
+    def getFillName(self):
+        return self.__fill_color_name
+        
+    def getFillValue(self):
+        return self.__fill_color_value
         
 
     def cloneProp(self, other):
@@ -54,10 +71,34 @@ class Primitive:
             elem.set('stroke-opacity', f'{self.stroke_opacity}')
 
         if self.fill:
-            elem.set('fill', self.fill)
+            isHex, color = convertColor(self.fill)
+
+            if isHex:
+                name = "hex " + self.fill.strip('#')
+                self.__fill_color_name = name
+                self.__fill_color_value = color
+
+                elem.set('fill', name)
+            else:
+                self.__fill_color_name = None
+                self.__fill_color_value = None
+                
+                elem.set('fill', self.fill)
 
         if self.stroke:
-            elem.set('stroke', self.stroke)
+            isHex, color = convertColor(self.stroke)
+
+            if isHex:
+                name = "hex " + self.stroke.strip('#')
+                self.__stroke_color_name = name
+                self.__stroke_color_value = color
+
+                elem.set('stroke', name)
+            else:
+                self.__stroke_color_name = None
+                self.__stroke_color_value = None
+                
+                elem.set('stroke', self.stroke)
         
         if self.dash:
             elem.set('dash', self.dash)
